#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-AjLBaZvy3ObGaemXZwwoXx
key:                  mime-mail-0.5.1-AjLBaZvy3ObGaemXZwwoXx
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  f7d9d60a135d4968104b7dd25ae21c1f
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mime-mail-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mime-mail
hs-libraries:         HSmime-mail-0.5.1-AjLBaZvy3ObGaemXZwwoXx
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-FfsKFWslEOoAvWp1oz7NnG
    blaze-builder-0.4.4.1-M4s5cE8K8cEVLaASoTkxk bytestring-0.11.5.3
    filepath-1.4.300.1 process-1.6.19.0
    random-1.2.1.3-IIwS2aSfjMyGbtdCPZwDHA text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

